@@ -1,8 +1,7 @@
-import sys
+import io
 import warnings
-import contextlib
 
-from io import TextIOWrapper, BytesIO
+from google.cloud.storage import Client
 
 
 class SuppressWarningsMixin:
@@ -12,10 +11,11 @@ class SuppressWarningsMixin:
         # Suppress unclosed socket warnings
         warnings.simplefilter("ignore", ResourceWarning)
 
-@contextlib.contextmanager
-def encoded_bytes_stream():
-    old_stdout = sys.stdout
-    sys.stdout = TextIOWrapper(BytesIO(), sys.stdout.encoding)
-    yield
-    sys.stdout.close()
-    sys.stdout = old_stdout
+
+def upload_data(uri: str, data: bytes):
+    if uri.startswith("gs://"):
+        bucket, key = uri[5:].split("/", 1)
+        Client().bucket(bucket).blob(key).upload_from_file(io.BytesIO(data))
+    else:
+        with open(uri, "wb") as fh:
+            fh.write(data)
